//
//  OptionsViewController.m
//  TGXF
//
//  Created by James Hudson on 2/03/2014.
//  Copyright (c) 2014 James Hudson. All rights reserved.
//

#import "OptionsViewController.h"

@interface OptionsViewController ()
@property (strong, nonatomic) IBOutlet UISlider *frameResolutionSlider;
@property (strong, nonatomic) IBOutlet UISlider *framesPerSecondSlider;
@property (strong, nonatomic) IBOutlet UISlider *maxErrorsSlider;
@property (strong, nonatomic) IBOutlet UISlider *timeoutSlider;

@end

@implementation OptionsViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    UIImageView *imageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"backdrop.png"]];
    [self.tableView setBackgroundView:imageView];
    
    self.title = NSLocalizedString(@"Options", @"settings title");
    
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    switch([defaults integerForKey: @"FrameResolution"]) {
            // actual values are 1 (21x21), 2 (25x25), 8 (49x49), 15 (77x77)
        case 1: self.frameResolutionSlider.value = 0; break;
        case 2: self.frameResolutionSlider.value = 1; break;
        case 8: self.frameResolutionSlider.value = 2; break;
        case 15: self.frameResolutionSlider.value = 3; break;
    }
    
    switch([defaults integerForKey: @"FramesPerSecond"]) {
        case 1: self.framesPerSecondSlider.value = 0; break;
        case 2: self.framesPerSecondSlider.value = 1; break;
        case 5: self.framesPerSecondSlider.value = 2; break;
        case 8: self.framesPerSecondSlider.value = 3; break;
        case 10: self.framesPerSecondSlider.value = 4; break;
    }
  
    switch([defaults integerForKey: @"MaxErrors"]) {
        case 0: self.maxErrorsSlider.value = 0; break;
        case 5: self.maxErrorsSlider.value = 1; break;
        case 10: self.maxErrorsSlider.value = 2; break;
        case 50: self.maxErrorsSlider.value = 3; break;
    }
    
    switch([defaults integerForKey: @"Timeout"]) {
        case 0: self.timeoutSlider.value = 0; break;
        case 5: self.timeoutSlider.value = 1; break;
        case 10: self.timeoutSlider.value = 2; break;
        case 50: self.timeoutSlider.value = 3; break;
    }
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


- (int) snappingSliderGetIndex: (id) control {
    
    UISlider * slider = (UISlider *) control;
    
    slider.value = floorf(slider.value+0.5f);
    
    return (int)slider.value;
}

- (IBAction)frameResolutionChanged:(id)sender {
    
    NSUserDefaults * defaults =[NSUserDefaults standardUserDefaults];

    NSString * key = @"FrameResolution";
    
    switch ([self snappingSliderGetIndex: sender]) {
        case 0:
            [defaults setInteger:1 forKey:key];
            break;
        case 1:
            [defaults setInteger:2 forKey:key];
            break;
        case 2:
            [defaults setInteger:8 forKey:key];
            break;
        case 3:
            [defaults setInteger:15 forKey:key];
            break;
    }
    
    [[NSUserDefaults standardUserDefaults] synchronize];
}

- (IBAction)framesPerSecondChanged:(id)sender {
    
    NSUserDefaults * defaults =[NSUserDefaults standardUserDefaults];
    
    NSString * key = @"FramesPerSecond";
    
    switch ([self snappingSliderGetIndex: sender]) {
        case 0:
            [defaults setInteger:1 forKey: key];
            break;
        case 1:
            [defaults setInteger:2 forKey: key];
            break;
        case 2:
            [defaults setInteger:5 forKey: key];
            break;
        case 3:
            [defaults setInteger:8 forKey: key];
            break;
        case 4:
            [defaults setInteger:10 forKey: key];
            break;
    }
    
    [[NSUserDefaults standardUserDefaults] synchronize];
}

- (IBAction)maxErrorChanged:(id)sender {
    NSUserDefaults * defaults =[NSUserDefaults standardUserDefaults];
    
    NSString * key = @"MaxErrors";
    
    switch ([self snappingSliderGetIndex: sender]) {
        case 0:
            [defaults setInteger:0 forKey: key];
            break;
        case 1:
            [defaults setInteger:5 forKey: key];
            break;
        case 2:
            [defaults setInteger:10 forKey: key];
            break;
        case 3:
            [defaults setInteger:50 forKey: key];
            break;
    }
    
    [[NSUserDefaults standardUserDefaults] synchronize];
}
- (IBAction)timeoutChanged:(id)sender {
    NSUserDefaults * defaults =[NSUserDefaults standardUserDefaults];
    
    NSString * key = @"Timeout";
    
    switch ([self snappingSliderGetIndex: sender]) {
        case 0:
            [defaults setInteger:0 forKey: key];
            break;
        case 1:
            [defaults setInteger:5 forKey: key];
            break;
        case 2:
            [defaults setInteger:10 forKey: key];
            break;
        case 3:
            [defaults setInteger:50 forKey: key];
            break;
    }
    [[NSUserDefaults standardUserDefaults] synchronize];
}


/*
#pragma mark - Navigation

// In a story board-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}

 */

@end
